# cowin-api
Co-WIN APIs to register for vaccination, to book a vaccination appointment from partner applications. These APIs have restricted access. Please contact Ministry of Health and Family Welfare, Government of India to get access to these APIs. <i>[Updated on 25 Apr 2021]</i>

This Python package is automatically generated by the
[Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project with
[fastapi_client](https://github.com/dmontagu/fastapi_client) extension:

- API version: 2.1.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.cowin.gov.in](https://www.cowin.gov.in)

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import cowin_api
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import cowin_api
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

from __future__ import print_function
import cowin_api.api_client import ApiClient, AsyncApis, SyncApis
from pprint import pprint

client = ApiClient(host="https://api.demo.co-vin.in/api")
sync_apis = SyncApis(client)
async_apis = AsyncApis(client)

# TODO: get real version of usage
pet_1 = sync_apis.pet_api.get_pet_by_id(pet_id=1)
assert isinstance(pet_1, Pet)

async def get_pet_2() -> Pet:
    pet_2 = await async_apis.pet_api.get_pet_by_id(pet_id=2)
    assert isinstance(pet_2, Pet)
    return pet_2
```
## Documentation for API Endpoints

TODO

## Documentation For Models

TODO

## Documentation For Authorization

TODO

## Author


